@@ -1,6 +1,6 @@
 ops <- list(
   "+",
-  #"-",
+  # "-",
   "=",
   "==",
   "!=",
@@ -21,12 +21,41 @@ ops <- list(
   "||",
   "&",
   "&&",
-  rex("%", except_any_of("%"), "%"))
+  rex("%", except_any_of("%"), "%")
+)
 
 #' Commented code linter
 #'
 #' Check that there is no commented code outside roxygen blocks.
 #'
+#' @examples
+#' # will produce lints
+#' lint(
+#'   text = "# x <- 1",
+#'   linters = commented_code_linter()
+#' )
+#'
+#' lint(
+#'   text = "x <- f() # g()",
+#'   linters = commented_code_linter()
+#' )
+#'
+#' lint(
+#'   text = "x + y # + z[1, 2]",
+#'   linters = commented_code_linter()
+#' )
+#'
+#' # okay
+#' lint(
+#'   text = "x <- 1; x <- f(); x + y",
+#'   linters = commented_code_linter()
+#' )
+#'
+#' lint(
+#'   text = "#' x <- 1",
+#'   linters = commented_code_linter()
+#' )
+#'
 #' @evalRd rd_tags("commented_code_linter")
 #' @seealso [linters] for a complete list of linters available in lintr.
 #' @export
@@ -50,13 +79,13 @@ commented_code_linter <- function() {
     if (!is_lint_level(source_expression, "file")) {
       return(list())
     }
-    all_comment_nodes <- xml2::xml_find_all(source_expression$full_xml_parsed_content, "//COMMENT")
-    all_comments <- xml2::xml_text(all_comment_nodes)
+    all_comment_nodes <- xml_find_all(source_expression$full_xml_parsed_content, "//COMMENT")
+    all_comments <- xml_text(all_comment_nodes)
     code_candidates <- re_matches(all_comments, code_candidate_regex, global = FALSE, locations = TRUE)
     extracted_code <- code_candidates[, "code"]
     # ignore trailing ',' when testing for parsability
-    extracted_code <- rex::re_substitutes(extracted_code, rex::rex(",", any_spaces, end), "")
-    extracted_code <- rex::re_substitutes(extracted_code, rex::rex(start, any_spaces, ","), "")
+    extracted_code <- re_substitutes(extracted_code, rex(",", any_spaces, end), "")
+    extracted_code <- re_substitutes(extracted_code, rex(start, any_spaces, ","), "")
     is_parsable <- which(vapply(extracted_code, parsable, logical(1L)))
 
     lint_list <- xml_nodes_to_lints(
@@ -96,6 +125,39 @@ parsable <- function(x) {
 #'
 #' @param todo Vector of strings that identify TODO comments.
 #'
+#' @examples
+#' # will produce lints
+#' lint(
+#'   text = "x + y # TODO",
+#'   linters = todo_comment_linter()
+#' )
+#'
+#' lint(
+#'   text = "pi <- 1.0 # FIXME",
+#'   linters = todo_comment_linter()
+#' )
+#'
+#' lint(
+#'   text = "x <- TRUE # hack",
+#'   linters = todo_comment_linter(todo = c("todo", "fixme", "hack"))
+#' )
+#'
+#' # okay
+#' lint(
+#'   text = "x + y # my informative comment",
+#'   linters = todo_comment_linter()
+#' )
+#'
+#' lint(
+#'   text = "pi <- 3.14",
+#'   linters = todo_comment_linter()
+#' )
+#'
+#' lint(
+#'   text = "x <- TRUE",
+#'   linters = todo_comment_linter()
+#' )
+#'
 #' @evalRd rd_tags("todo_comment_linter")
 #' @seealso [linters] for a complete list of linters available in lintr.
 #' @export
