@@ -64,8 +64,8 @@ regex_subset_linter <- function() {
       and expr[position() = {arg_pos} ] = parent::expr/expr[1]
     ]
   "
-  grep_xpath <- glue::glue(xpath_fmt, calls = c("grepl", "grep"), arg_pos = 3L)
-  stringr_xpath <- glue::glue(xpath_fmt, calls = c("str_detect", "str_which"), arg_pos = 2L)
+  grep_xpath <- glue(xpath_fmt, calls = c("grepl", "grep"), arg_pos = 3L)
+  stringr_xpath <- glue(xpath_fmt, calls = c("str_detect", "str_which"), arg_pos = 2L)
 
   Linter(function(source_expression) {
     if (!is_lint_level(source_expression, "expression")) {
@@ -74,7 +74,7 @@ regex_subset_linter <- function() {
 
     xml <- source_expression$xml_parsed_content
 
-    grep_expr <- xml2::xml_find_all(xml, grep_xpath)
+    grep_expr <- xml_find_all(xml, grep_xpath)
 
     grep_lints <- xml_nodes_to_lints(
       grep_expr,
@@ -84,7 +84,7 @@ regex_subset_linter <- function() {
       type = "warning"
     )
 
-    stringr_expr <- xml2::xml_find_all(xml, stringr_xpath)
+    stringr_expr <- xml_find_all(xml, stringr_xpath)
 
     stringr_lints <- xml_nodes_to_lints(
       stringr_expr,
