@@ -1,11 +1,11 @@
 test_that("brace_linter lints braces correctly", {
   open_curly_msg <- rex::rex(
-    "Opening curly braces should never go on their own line and should always be followed by a new line."
+    "Opening curly braces should never go on their own line"
   )
-  closed_curly_msg <- rex::rex(paste(
-    "Closing curly-braces should always be on their own line,",
+  closed_curly_msg <- rex::rex(
+    "Closing curly-braces should always be on their own line, ",
     "unless they are followed by an else."
-  ))
+  )
 
   linter <- brace_linter()
   expect_lint("blah", NULL, linter)
@@ -73,16 +73,6 @@ test_that("brace_linter lints braces correctly", {
     linter
   )
 
-  expect_lint(
-    trim_some("
-      out <- lapply(stuff, function(i) {
-        do_something(i)
-      }) %>% unlist
-    "),
-    NULL,
-    linter
-  )
-
   # ,<\n>{ is allowed
   expect_lint(
     trim_some("
@@ -148,22 +138,6 @@ test_that("brace_linter lints braces correctly", {
     linter
   )
 
-  # %>%\n{ is allowed
-  expect_lint(
-    trim_some("
-    letters %>%
-      {
-        tibble(
-          lo = .,
-          hi = toupper(.)
-        )
-      } %>%
-      mutate(row_id = row_number())
-    "),
-    NULL,
-    linter
-  )
-
   # (\n{ is allowed optionally
   expect_lint(
     trim_some("
@@ -224,12 +198,12 @@ test_that("brace_linter lints braces correctly", {
 
 test_that("brace_linter lints spaces before open braces", {
   linter <- brace_linter()
-  msg <- rex::rex("There should be a space before an opening curly brace.")
+  lint_msg <- rex::rex("There should be a space before an opening curly brace.")
 
   expect_lint(
     "blah <- function(){\n}",
     list(
-      message = msg,
+      message = lint_msg,
       column_number = 19L
     ),
     linter
@@ -238,7 +212,7 @@ test_that("brace_linter lints spaces before open braces", {
   expect_lint(
     "\nblah <- function(){\n\n\n}",
     list(
-      message = msg,
+      message = lint_msg,
       column_number = 19L
     ),
     linter
@@ -248,8 +222,8 @@ test_that("brace_linter lints spaces before open braces", {
   expect_lint(
     "a <- if (a){\n} else{\n}",
     list(
-      list(message = msg, line_number = 1L, column_number = 12L),
-      list(message = msg, line_number = 2L, column_number = 7L)
+      list(message = lint_msg, line_number = 1L, column_number = 12L),
+      list(message = lint_msg, line_number = 2L, column_number = 7L)
     ),
     linter
   )
@@ -257,14 +231,14 @@ test_that("brace_linter lints spaces before open braces", {
   # should lint repeat{
   expect_lint(
     "repeat{\nblah\n}",
-    list(message = msg, line_number = 1L, column_number = 7L),
+    list(message = lint_msg, line_number = 1L, column_number = 7L),
     linter
   )
 
   # should ignore strings and comments, as in regexes:
   expect_lint("grepl('(iss){2}', 'Mississippi')", NULL, linter)
   expect_lint(
-    "x <- 123 # dont flag (paren){brace} if inside a comment",
+    "x <- 123 # don't flag (paren){brace} if inside a comment",
     NULL,
     linter
   )
@@ -275,9 +249,9 @@ test_that("brace_linter lints spaces before open braces", {
                      {2}
     "),
     list(
-      rex::rex("Opening curly braces should never go on their own line and should always be followed by a new line."),
-      rex::rex("Closing curly-braces should always be on their own line, unless they are followed by an else.")
-    ), # , but not msg
+      rex::rex("Opening curly braces should never go on their own line"),
+      rex::rex("Closing curly-braces should always be on their own line")
+    ), # , but not lint_msg
     linter
   )
 })
@@ -348,6 +322,7 @@ test_that("brace_linter lints function expressions correctly", {
 
 test_that("brace_linter lints if/else matching braces correctly", {
   linter <- brace_linter()
+
   expect_lint("if (TRUE) 1 else 2", NULL, linter)
   expect_lint("if (TRUE) 1", NULL, linter)
 
@@ -409,3 +384,190 @@ test_that("brace_linter lints if/else matching braces correctly", {
     linter
   )
 })
+
+# Keep up to date with https://github.com/tidyverse/style/issues/191
+test_that("empty brace expressions are always allowed inline", {
+  expect_lint("while (FALSE) {}", NULL, brace_linter())
+  expect_lint("while (FALSE) { }", NULL, brace_linter())
+  # only applies when `{` is "attached" to the preceding token on the same line
+  expect_lint("while (FALSE)\n{}", rex::rex("Opening curly braces"), brace_linter())
+  expect_lint("while (FALSE)\n{ }", rex::rex("Opening curly braces"), brace_linter())
+  expect_lint("while (FALSE) {}", NULL, brace_linter(allow_single_line = TRUE))
+  expect_lint("while (FALSE) { }", NULL, brace_linter(allow_single_line = TRUE))
+})
+
+test_that("formula syntax is linted properly", {
+  linter <- brace_linter()
+  lint_msg_open <- rex::rex("Opening curly braces should never go on their own line")
+  lint_msg_closed <- rex::rex("Closing curly-braces should always be on their own line")
+
+  expect_lint(
+    trim_some("
+      map(
+        .x = 1:4,
+        .f = ~ {
+                .x + 1
+              }
+      )"),
+    NULL,
+    linter
+  )
+
+  expect_lint(
+    trim_some("
+      map(
+        .x = 1:4,
+        .f = ~ {.x + 1}
+      )"),
+    list(
+      list(message = lint_msg_open, line_number = 3L, column_number = 10L),
+      list(message = lint_msg_closed, line_number = 3L, column_number = 17L)
+    ),
+    linter
+  )
+
+  expect_lint(
+    trim_some("
+      map(
+        .x = 1:4,
+        .f = ~ { .x + 1
+              }
+      )"),
+    list(
+      list(message = lint_msg_open, line_number = 3L, column_number = 10L)
+    ),
+    linter
+  )
+
+  expect_lint(
+    trim_some("
+      map(
+        .x = 1:4,
+        .f = ~ {
+                .x + 1}
+      )"),
+    list(
+      list(message = lint_msg_closed, line_number = 4L, column_number = 17L)
+    ),
+    linter
+  )
+})
+
+test_that("code with pipes is handled correctly", {
+  linter <- brace_linter()
+  lint_msg_open <- rex::rex("Opening curly braces should never go on their own line")
+  lint_msg_closed <- rex::rex("Closing curly-braces should always be on their own line")
+
+  expect_lint(
+    trim_some("
+      out <- lapply(stuff, function(i) {
+        do_something(i)
+      }) %>% unlist
+    "),
+    NULL,
+    linter
+  )
+
+  expect_lint(
+    trim_some("
+      1:4 %!>% {
+          sum(.)
+        }
+    "),
+    NULL,
+    linter
+  )
+
+  # %>%\n{ is allowed
+  expect_lint(
+    trim_some("
+      1:4 %T>%
+        {
+          sum(.)
+        }
+    "),
+    NULL,
+    linter
+  )
+
+  expect_lint(
+    trim_some("
+      xx %<>% { sum(.)
+        }
+    "),
+    list(
+      list(message = lint_msg_open, line_number = 1L, column_number = 9L)
+    ),
+    linter
+  )
+
+  expect_lint(
+    trim_some("
+      x %>%
+        {
+          uvwxyz }
+    "),
+    list(
+      list(message = lint_msg_closed, line_number = 3L, column_number = 12L)
+    ),
+    linter
+  )
+
+  expect_lint(
+    trim_some("
+      1:4 %>%
+        { sum(.) }
+    "),
+    list(
+      list(message = lint_msg_closed, line_number = 2L, column_number = 12L)
+    ),
+    linter
+  )
+
+  expect_lint(
+    "1:4 %>% { sum(.) }",
+    list(
+      list(message = lint_msg_open, line_number = 1L, column_number = 9L),
+      list(message = lint_msg_closed, line_number = 1L, column_number = 18L)
+    ),
+    linter
+  )
+
+  skip_if_not_r_version("4.1.0")
+
+  expect_lint(
+    trim_some("
+      out <- lapply(stuff, function(i) {
+        do_something(i)
+      }) |> unlist()
+    "),
+    NULL,
+    linter
+  )
+
+  expect_lint(
+    "local({ 1:4 |> sum() })",
+    list(
+      list(message = lint_msg_open, line_number = 1L, column_number = 7L)
+    ),
+    linter
+  )
+})
+
+test_that("function shorthand is treated like 'full' function", {
+  skip_if_not_r_version("4.1.0")
+  linter <- brace_linter()
+
+  expect_lint("a <- \\() {  \n}", NULL, linter)
+  expect_lint(
+    trim_some("
+      x <- \\()
+              {2}
+    "),
+    list(
+      rex::rex("Opening curly braces should never go on their own line"),
+      rex::rex("Closing curly-braces should always be on their own line")
+    ),
+    linter
+  )
+})
