@@ -1,14 +1,16 @@
 test_that("expect_comparison_linter skips allowed usages", {
+  linter <- expect_comparison_linter()
+
   # there's no expect_ne() for this operator
-  expect_lint("expect_true(x != y)", NULL, expect_comparison_linter())
+  expect_lint("expect_true(x != y)", NULL, linter)
   # NB: also applies to tinytest, but it's sufficient to test testthat
-  expect_lint("testthat::expect_true(x != y)", NULL, expect_comparison_linter())
+  expect_lint("testthat::expect_true(x != y)", NULL, linter)
 
   # multiple comparisons are OK
-  expect_lint("expect_true(x > y || x > z)", NULL, expect_comparison_linter())
+  expect_lint("expect_true(x > y || x > z)", NULL, linter)
 
   # expect_gt() and friends don't have an info= argument
-  expect_lint("expect_true(x > y, info = 'x is bigger than y yo')", NULL, expect_comparison_linter())
+  expect_lint("expect_true(x > y, info = 'x is bigger than y yo')", NULL, linter)
 })
 
 test_that("expect_comparison_linter blocks simple disallowed usages", {
