@@ -26,6 +26,9 @@ test_that("pipe_call_linter skips allowed usages", {
   }
   ")
   expect_lint(lines, NULL, linter)
+
+  # extraction pipe uses RHS symbols
+  expect_lint("a %$% b", NULL, linter)
 })
 
 test_that("pipe_call_linter blocks simple disallowed usages", {
@@ -58,3 +61,31 @@ test_that("pipe_call_linter blocks simple disallowed usages", {
     pipe_call_linter()
   )
 })
+
+local({
+  pipes <- pipes(exclude = c("%$%", "|>"))
+  linter <- pipe_call_linter()
+  patrick::with_parameters_test_that(
+    "All pipe operators are caught",
+    {
+      expect_lint(sprintf("a %s foo()", pipe), NULL, linter)
+      expect_lint(sprintf("a %s foo", pipe), sprintf("`a %s foo`", pipe), linter)
+    },
+    pipe = pipes,
+    .test_name = names(pipes)
+  )
+})
+
+test_that("Multiple lints give custom messages", {
+  expect_lint(
+    trim_some("
+      a %>% b
+      c %T>% d
+    "),
+    list(
+      list(message = "%>%", line_number = 1L),
+      list(message = "%T>%", line_number = 2L)
+    ),
+    pipe_call_linter()
+  )
+})
